@@ -126,7 +126,7 @@ class IconItem : public QQuickItem
 
 public:
     explicit IconItem(QQuickItem *parent = nullptr);
-    ~IconItem();
+    ~IconItem() Q_DECL_OVERRIDE;
 
     void setSource(const QVariant &source);
     QVariant source() const;
@@ -202,14 +202,11 @@ private:
     QIcon m_icon;
     Plasma::Svg *m_svgIcon;
     QString m_svgIconName;
-    QPixmap m_pixmapIcon;
     QImage m_imageIcon;
     //this contains the raw variant it was passed
     QVariant m_source;
     Plasma::Svg::Status m_status;
 
-    QSizeF m_implicitSize;
-
     bool m_smooth;
     bool m_active;
     bool m_animated;
