@@ -24,7 +24,6 @@
 #include <QDir>
 #include <QFile>
 #include <QIcon>
-#include <QSignalMapper>
 #include <QTimer>
 
 #include <kactioncollection.h>
@@ -49,16 +48,15 @@ Q_DECLARE_METATYPE(AppletInterface *)
 
 AppletInterface::AppletInterface(DeclarativeAppletScript *script, const QVariantList &args, QQuickItem *parent)
     : AppletQuickItem(script->applet(), parent),
-      m_actionSignals(0),
-      m_configuration(0),
+      m_configuration(nullptr),
       m_appletScriptEngine(script),
       m_toolTipTextFormat(0),
-      m_toolTipItem(0),
+      m_toolTipItem(nullptr),
       m_args(args),
       m_backgroundHints(Plasma::Types::StandardBackground),
       m_hideOnDeactivate(true),
       m_oldKeyboardShortcut(0),
-      m_dummyNativeInterface(0),
+      m_dummyNativeInterface(nullptr),
       m_positionBeforeRemoval(QPointF(-1, -1))
 {
     qmlRegisterType<QAction>();
@@ -95,6 +93,14 @@ AppletInterface::AppletInterface(DeclarativeAppletScript *script, const QVariant
     connect(applet(), &Plasma::Applet::busyChanged,
             this, &AppletInterface::busyChanged);
 
+    connect(applet(), &Plasma::Applet::configurationRequiredChanged, this,
+            [this](bool configurationRequired, const QString &reason) {
+        Q_UNUSED(configurationRequired);
+        Q_UNUSED(reason);
+        emit configurationRequiredChanged();
+        emit configurationRequiredReasonChanged();
+    });
+
     connect(applet(), &Plasma::Applet::activated,
             this, &AppletInterface::activated);
 
@@ -450,14 +456,9 @@ void AppletInterface::setAction(const QString &name, const QString &text, const
         Q_ASSERT(!m_actions.contains(name));
         m_actions.append(name);
 
-        if (!m_actionSignals) {
-            m_actionSignals = new QSignalMapper(this);
-            connect(m_actionSignals, SIGNAL(mapped(QString)),
-                    appletScript(), SLOT(executeAction(QString)));
-        }
-
-        connect(action, SIGNAL(triggered()), m_actionSignals, SLOT(map()));
-        m_actionSignals->setMapping(action, name);
+        connect(action, &QAction::triggered, this, [this, name] {
+            executeAction(name);
+        });
     }
 
     if (!icon.isEmpty()) {
@@ -475,15 +476,7 @@ void AppletInterface::removeAction(const QString &name)
 {
     Plasma::Applet *a = applet();
     QAction *action = a->actions()->action(name);
-
-    if (action) {
-        if (m_actionSignals) {
-            m_actionSignals->removeMappings(action);
-        }
-
-        delete action;
-    }
-
+    delete action;
     m_actions.removeAll(name);
 }
 
@@ -650,10 +643,10 @@ QString AppletInterface::downloadPath(const QString &file)
 
 QString AppletInterface::downloadPath() const
 {
-    const QString downloadDir = QStandardPaths::writableLocation(QStandardPaths::DownloadLocation) + "/Plasma/" + applet()->pluginMetaData().pluginId() + '/';
+    const QString downloadDir = QStandardPaths::writableLocation(QStandardPaths::DownloadLocation) + QStringLiteral("/Plasma/") + applet()->pluginMetaData().pluginId() + QLatin1Char('/');
 
     if (!QFile::exists(downloadDir)) {
-        QDir dir(QChar('/'));
+        QDir dir({ QLatin1Char('/') });
         dir.mkpath(downloadDir);
     }
 
@@ -662,7 +655,7 @@ QString AppletInterface::downloadPath() const
 
 QStringList AppletInterface::downloadedFiles() const
 {
-    const QString downloadDir = QStandardPaths::writableLocation(QStandardPaths::DownloadLocation) + "/Plasma/" + applet()->pluginMetaData().pluginId() + '/';
+    const QString downloadDir = QStandardPaths::writableLocation(QStandardPaths::DownloadLocation) + QStringLiteral("/Plasma/") + applet()->pluginMetaData().pluginId() + QLatin1Char('/');
     QDir dir(downloadDir);
     return dir.entryList(QDir::Files | QDir::NoSymLinks | QDir::Readable);
 }
@@ -671,9 +664,10 @@ void AppletInterface::executeAction(const QString &name)
 {
     if (qmlObject()->rootObject()) {
         const QMetaObject *metaObj = qmlObject()->rootObject()->metaObject();
-        QString actionMethodName = QString("action_" + name);
-        if (metaObj->indexOfMethod(QMetaObject::normalizedSignature((actionMethodName + "()").toLatin1())) != -1) {
-            QMetaObject::invokeMethod(qmlObject()->rootObject(), actionMethodName.toLatin1(), Qt::DirectConnection);
+        const QByteArray actionMethodName = "action_" + name.toUtf8();
+        const QByteArray actionFunctionName = actionMethodName + QByteArray("()");
+        if (metaObj->indexOfMethod(QMetaObject::normalizedSignature(actionFunctionName.constData()).constData()) != -1) {
+            QMetaObject::invokeMethod(qmlObject()->rootObject(), actionMethodName.constData(), Qt::DirectConnection);
         } else {
             QMetaObject::invokeMethod(qmlObject()->rootObject(), "actionTriggered", Qt::DirectConnection, Q_ARG(QVariant, name));
         }
